# Kubernetes Baseline

* [ArgoCD](https://argoproj.github.io/cd/)
  * [NGINX Ingress Controller](https://kubernetes.github.io/ingress-nginx/)
  * [cert-manager](https://cert-manager.io/)
    * selfsigned issuer
    * LetsEncrypt issuers (Prod and Staging)
  * [zabbix-proxy](https://git.zabbix.com/projects/ZT/repos/kubernetes-helm/browse?at=refs%2Fheads%2Frelease%2F6.4)
  * [loki](https://grafana.com/docs/loki/latest/)
  * [keel](https://keel.sh)
  * [reloader](https://github.com/stakater/Reloader)

## Installation (k3s + baseline)

`ansible-playbook -i <host|ip>, pb_install.yml`

## Installation (baseline only)

make sure kubectl is configure to reach the destination cluster, then:

`kubectl apply -f argocd-init.yml`

## Notes

### ArgoCD

To retrieve the initial admin password use
`kubectl -n argocd get secret argocd-initial-admin-secret -o jsonpath="{.data.password}" | base64 -d`

To change the password follow [Argocd account update password](https://argo-cd.readthedocs.io/en/stable/user-guide/commands/argocd_account_update-password/).

### Linode

PROXY protocol needs to be enabled for ingress-nginx to see the clients IP in ingress log.

Add the PROXY protocol annotation to the ingress-nginx service:

```
annotations:
    service.beta.kubernetes.io/linode-loadbalancer-proxy-protocol: v2
```

Update the ingress-nginx ConfigMap to make nginx expect PROXY protocol data:

```
data:
  use-proxy-protocol: "true"
```

#### cert-manager

> However, when you have the PROXY protocol enabled, the external load balancer does modify the traffic, prepending the PROXY line before each TCP connection. If you connect directly to the web server internally, bypassing the external load balancer, then it will receive traffic without the PROXY line.
>
> This is particularly a problem when using cert-manager for provisioning SSL certificates.

After enabling the PROXY protocol cert-manager is unable to perform a self check ("propagation check failed", "failed to perform self check GET request").

[hairpin-proxy](https://github.com/compumike/hairpin-proxy) adds PROXY protocol support for internal-to-LoadBalancer traffic for Kubernetes Ingress users, specifically for cert-manager self-checks (no further configuration needed).
